Crate kcr_telemetry_istio_io

Crate kcr_telemetry_istio_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the telemetry.istio.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

telemetry.istio.io/v1

  • Telemetry

telemetry.istio.io/v1alpha1

  • Telemetry

Modules

v1
v1alpha1